@@ -48,7 +48,7 @@ void dump_core()
 	abort();
 }
 
-void *operator new (size_t size)
+void *operator new (size_t size) CXX__NEW_THROW
 {
 #ifdef LARGE_MEMORY_THRES
 	if (size > LARGE_MEMORY_THRES) {
@@ -75,7 +75,7 @@ void operator delete (void *p) CXX__DELETE_THROW
 
 #ifdef CXX__HAVE_ARRAY_NEW
 
-void *operator new[] (size_t size)
+void *operator new[] (size_t size) CXX__NEW_THROW
 {
 #ifdef LARGE_MEMORY_THRES
 	if (size > LARGE_MEMORY_THRES) {
