@@ -33,10 +33,10 @@ void dump_core();
 // new/delete operators
 //
 
-void *operator new (size_t s);
+void *operator new (size_t s) CXX__NEW_THROW;
 void operator delete (void *p) CXX__DELETE_THROW;
 #ifdef CXX__HAVE_ARRAY_NEW
-void *operator new[] (size_t s);
+void *operator new[] (size_t s) CXX__NEW_THROW;
 void operator delete[] (void *p) CXX__DELETE_THROW;
 #endif	/* CXX__HAVE_ARRAY_NEW */
 
